import chalk from 'chalk';
import { sync as globSync } from 'glob';
import { extractResolvers } from 'graphql-resolvers-finder';

export async function listResolvers(glob: string, baseDir: string, schemaPointer: string | null): Promise<void> {
  console.log(chalk.gray(`Looking for source code files using glob "${glob}"...`));
  const relevantFiles = globSync(glob, {
    absolute: true,
    cwd: process.cwd(),
  });

  if (relevantFiles.length === 0) {
    console.log(chalk.redBright(`Unable to find any matching for "${glob}" expression!`));

    return;
  } else {
    console.log(chalk.gray(`Found total of ${relevantFiles.length} source code files.`));
    console.log(chalk.white('Looking for resolvers...'));

    try {
      const foundResolvers = extractResolvers({ files: relevantFiles, baseDir });
      const keys = Object.keys(foundResolvers);

      if (keys.length === 0) {
        console.log(chalk.redBright('Unable to find any resolvers!'));
        return;
      } else {
        console.log(chalk.white(`Found total of ${keys.length} resolvers:`));

        for (const key of keys) {
          const item = foundResolvers[key];
          console.log(chalk.white(`\t${key} -> ${item.filepath} (line ${item.node.loc.start.line}, col ${item.node.loc.start.column})`));
        }
      }
    } catch (e) {
      console.log(chalk.redBright(e));
      process.exit(1);
    }
  }
}
