#!/usr/bin/env node

import * as commander from 'commander';
import { join } from 'path';
import { listResolvers } from './commands/list';
import { findResolver } from './commands/find';

commander
  .command('list')
  .description('Lists all found resolvers')
  .option('-i, --input <path>', 'A glob expression pointing to your source code files', join(process.cwd(), './*.{ts,js}'))
  .option('-s, --schema <point-to-schema>', 'A pointer to your GraphQL schema, optional', join(process.cwd(), './*.{ts,js}'))
  .option('-b, --base-dir <path>', 'A path to be used as base dir', null)
  .action((cmd: commander.Command) => {
    listResolvers(cmd.input, cmd.baseDir, cmd.schemaPointer);
  });

commander
  .command('find')
  .description('Find a specific resolver')
  .option('-i, --input <path>', 'A glob expression pointing to your source code files', join(process.cwd(), './*.{ts,js}'))
  .option('-s, --type <type-name>', 'The type name, optional if schema has been provided', null)
  .option('-s, --field <field-name>', 'The field name, optional', null)
  .option('-s, --schema <point-to-schema>', 'A pointer to your GraphQL schema, optional if type has been provided', null)
  .option('-b, --base-dir <path>', 'A path to be used as base dir, optional', null)
  .action((cmd: commander.Command) => {
    findResolver(cmd.input, cmd.baseDir, cmd.type, cmd.field, cmd.schema);
  });

commander.command('*').action(() => commander.help());
commander.parse(process.argv);
